ardt.preprocessors.filters.NK2PowerlineFilter.NK2PowerlineFilter
================================================================

.. currentmodule:: ardt.preprocessors.filters.NK2PowerlineFilter

.. autoclass:: NK2PowerlineFilter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~NK2PowerlineFilter.__init__
      ~NK2PowerlineFilter.process_signal
      ~NK2PowerlineFilter.resolve
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~NK2PowerlineFilter.context
   
   